import {
  select,
  scaleOrdinal,
  schemeSpectral
} from 'd3';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { choroplethMap } from './choroplethMap';

const svg = select('svg');
const choroplethMapG = svg.append('g');
const colorLegendG = svg.append('g')
  .attr('transform', `translate(30, 300)`);

const colorScale = scaleOrdinal();	// apply 10 prechosen colors: scaleOrdinal(schemeCategory10)

// const colorValue = d => d.properties.income_grp;
const colorValue = d => d.properties.economy;

let selectedColorValue;
let features;

const onClick = d => {
  selectedColorValue = d
  render();
};

loadAndProcessData().then(countries => {  // load and process data in another module & sets a state & invoke rendering
  features = countries.features;
  render();
});

const render = () => {
  colorScale
    .domain(features.map(colorValue))  // set the domain to economy values (this removes duplicates: turns to unique vals)
    .domain(colorScale.domain().sort().reverse())  //  set the domain again to sort the uniqued domain array
    .range(schemeSpectral[colorScale.domain().length]);  // apply given # of prechosen colors with schemeSpectral[]
  
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 10,
    backgroundRectWidth: 235,
    onClick,
    selectedColorValue
  });
  
  choroplethMapG.call(choroplethMap, {
    features,
    colorScale,
    colorValue,
    selectedColorValue
  });
};